pub const BANNER: &str = r"  _  ______            _
 | |/ /  _ \  __ _ ___| |__
 | ' /| | | |/ _` / __| '_ \
 | . \| |_| | (_| \__ \ | | |
 |_|\_\____/ \__,_|___/_| |_|
";
